@@ -7,13 +7,17 @@ import os
 import platform
 import time
 import warnings
-from collections import Iterable
 from itertools import islice
 
 import requests
 
 from .utils import str_types
 
+try:
+    from collections.abc import Iterable
+except ImportError:
+    from collections import Iterable
+
 try:
     from pandas import DataFrame
     from pandas.io.json import json_normalize
@@ -152,7 +156,7 @@ class BiothingClient(object):
         debug = params.pop('debug', False)
         return_raw = params.pop('return_raw', False)
         headers = {'user-agent': self.default_user_agent}
-        res = requests.get(url, json=params, headers=headers)
+        res = requests.get(url, data=params, headers=headers)
         from_cache = getattr(res, 'from_cache', False)
         if debug:
             return from_cache, res
@@ -169,7 +173,7 @@ class BiothingClient(object):
     def _post(self, url, params, verbose=True):
         return_raw = params.pop('return_raw', False)
         headers = {'user-agent': self.default_user_agent}
-        res = requests.post(url, json=params, headers=headers)
+        res = requests.post(url, data=params, headers=headers)
         from_cache = getattr(res, 'from_cache', False)
         if self.raise_for_status:
             # raise requests.exceptions.HTTPError if not 200
